==> zio-aws-clouddirectory_3-5.17.155.1-sources.jar: zio/aws/clouddirectory/model/BatchListIncomingTypedLinks.scala <==
package zio.aws.clouddirectory.model
import java.lang.Integer
import zio.aws.clouddirectory.model.primitives.{NumberResults, NextToken}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class BatchListIncomingTypedLinks(
    objectReference: zio.aws.clouddirectory.model.ObjectReference,
    filterAttributeRanges: Option[
      Iterable[zio.aws.clouddirectory.model.TypedLinkAttributeRange]
    ] = None,
    filterTypedLink: Option[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName
    ] = None,
    nextToken: Option[NextToken] = None,
    maxResults: Option[NumberResults] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks = {
    import BatchListIncomingTypedLinks.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
      .builder()
      .objectReference(objectReference.buildAwsValue())
      .optionallyWith(
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filterAttributeRanges)
      .optionallyWith(filterTypedLink.map(value => value.buildAwsValue()))(
        _.filterTypedLink
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => NumberResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.BatchListIncomingTypedLinks.ReadOnly =
    zio.aws.clouddirectory.model.BatchListIncomingTypedLinks
      .wrap(buildAwsValue())
}
object BatchListIncomingTypedLinks {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.clouddirectory.model.BatchListIncomingTypedLinks =
      zio.aws.clouddirectory.model.BatchListIncomingTypedLinks(
        objectReference.asEditable,
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        filterTypedLink.map(value => value.asEditable),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def objectReference: zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    def filterAttributeRanges: Option[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ]
    def filterTypedLink: Option[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ]
    def nextToken: Option[NextToken]
    def maxResults: Option[NumberResults]
    def getObjectReference: ZIO[
      Any,
      Nothing,
      zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    ] = ZIO.succeed(objectReference)
    def getFilterAttributeRanges: ZIO[Any, AwsError, List[
      zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly
    ]] =
      AwsError.unwrapOptionField("filterAttributeRanges", filterAttributeRanges)
    def getFilterTypedLink: ZIO[
      Any,
      AwsError,
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = AwsError.unwrapOptionField("filterTypedLink", filterTypedLink)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, NumberResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
  ) extends zio.aws.clouddirectory.model.BatchListIncomingTypedLinks.ReadOnly {
    override val objectReference
        : zio.aws.clouddirectory.model.ObjectReference.ReadOnly =
      zio.aws.clouddirectory.model.ObjectReference.wrap(impl.objectReference())
    override val filterAttributeRanges: Option[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ] = scala
      .Option(impl.filterAttributeRanges())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.clouddirectory.model.TypedLinkAttributeRange.wrap(item)
        }.toList
      )
    override val filterTypedLink: Option[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = scala
      .Option(impl.filterTypedLink())
      .map(value =>
        zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.wrap(value)
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
    override val maxResults: Option[NumberResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.NumberResults(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
  ): zio.aws.clouddirectory.model.BatchListIncomingTypedLinks.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-clouddirectory_3-5.17.193.1-sources.jar: zio/aws/clouddirectory/model/BatchListIncomingTypedLinks.scala <==
package zio.aws.clouddirectory.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.clouddirectory.model.primitives.{NumberResults, NextToken}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class BatchListIncomingTypedLinks(
    objectReference: zio.aws.clouddirectory.model.ObjectReference,
    filterAttributeRanges: Optional[
      Iterable[zio.aws.clouddirectory.model.TypedLinkAttributeRange]
    ] = Optional.Absent,
    filterTypedLink: Optional[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    maxResults: Optional[NumberResults] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks = {
    import BatchListIncomingTypedLinks.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
      .builder()
      .objectReference(objectReference.buildAwsValue())
      .optionallyWith(
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filterAttributeRanges)
      .optionallyWith(filterTypedLink.map(value => value.buildAwsValue()))(
        _.filterTypedLink
      )
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        maxResults.map(value => NumberResults.unwrap(value): Integer)
      )(_.maxResults)
      .build()
  }
  def asReadOnly
      : zio.aws.clouddirectory.model.BatchListIncomingTypedLinks.ReadOnly =
    zio.aws.clouddirectory.model.BatchListIncomingTypedLinks
      .wrap(buildAwsValue())
}
object BatchListIncomingTypedLinks {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.clouddirectory.model.BatchListIncomingTypedLinks =
      zio.aws.clouddirectory.model.BatchListIncomingTypedLinks(
        objectReference.asEditable,
        filterAttributeRanges.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        filterTypedLink.map(value => value.asEditable),
        nextToken.map(value => value),
        maxResults.map(value => value)
      )
    def objectReference: zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    def filterAttributeRanges: Optional[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ]
    def filterTypedLink: Optional[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ]
    def nextToken: Optional[NextToken]
    def maxResults: Optional[NumberResults]
    def getObjectReference: ZIO[
      Any,
      Nothing,
      zio.aws.clouddirectory.model.ObjectReference.ReadOnly
    ] = ZIO.succeed(objectReference)
    def getFilterAttributeRanges: ZIO[Any, AwsError, List[
      zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly
    ]] =
      AwsError.unwrapOptionField("filterAttributeRanges", filterAttributeRanges)
    def getFilterTypedLink: ZIO[
      Any,
      AwsError,
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = AwsError.unwrapOptionField("filterTypedLink", filterTypedLink)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getMaxResults: ZIO[Any, AwsError, NumberResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
  ) extends zio.aws.clouddirectory.model.BatchListIncomingTypedLinks.ReadOnly {
    override val objectReference
        : zio.aws.clouddirectory.model.ObjectReference.ReadOnly =
      zio.aws.clouddirectory.model.ObjectReference.wrap(impl.objectReference())
    override val filterAttributeRanges: Optional[
      List[zio.aws.clouddirectory.model.TypedLinkAttributeRange.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.filterAttributeRanges())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.clouddirectory.model.TypedLinkAttributeRange.wrap(item)
        }.toList
      )
    override val filterTypedLink: Optional[
      zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.filterTypedLink())
      .map(value =>
        zio.aws.clouddirectory.model.TypedLinkSchemaAndFacetName.wrap(value)
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.clouddirectory.model.primitives.NextToken(value))
    override val maxResults: Optional[NumberResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value =>
        zio.aws.clouddirectory.model.primitives.NumberResults(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.clouddirectory.model.BatchListIncomingTypedLinks
  ): zio.aws.clouddirectory.model.BatchListIncomingTypedLinks.ReadOnly =
    new Wrapper(impl)
}
